pub struct DragState { /* private fields */ }Expand description
State for tracking a popup drag or resize operation.
Implementations
Sourceimpl DragState
impl DragState
pub fn new() -> Self
Sourcepub fn begin(&mut self, popup: Rect, col: u16, row: u16, zone: Zone)
pub fn begin(&mut self, popup: Rect, col: u16, row: u16, zone: Zone)
Start a drag based on the zone at the click position.
Sourcepub fn update(&self, area: Rect, col: u16, row: u16) -> DragUpdate
pub fn update(&self, area: Rect, col: u16, row: u16) -> DragUpdate
Update the drag and return the new popup state.
Returns None/DragUpdate::None if no drag is in progress.
Sourcepub fn is_dragging(&self) -> bool
pub fn is_dragging(&self) -> bool
Whether a drag is in progress.